==> igniteui-webcomponents-inputs-4.3.3-beta.0.tgz: package/esm2015/lib/XIconButtonBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XButtonBridge } from "./XButtonBridge";
import { enumGetBox, EnumUtil, markType } from "igniteui-webcomponents-core";
import { XIconBridge } from "./XIconBridge";
import { BaseControlTheme_$type } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let XIconButtonBridge = /*@__PURE__*/ (() => {
    class XIconButtonBridge extends XButtonBridge {
        constructor(a, b) {
            super(a);
            this.al = null;
            this.al = new XIconBridge(b);
        }
        getTargetForBuildInProperty(a, b) {
            switch (b) {
                case 15:
                case 16:
                case 44:
                case 45:
                case 46:
                case 47:
                case 48:
                case 49: return this.al.t;
            }
            return super.getTargetForBuildInProperty(a, b);
        }
        getTargetForProperty(a, b) {
            switch (a) {
                case 16:
                case 15:
                case 17: return this.al.t.view.o;
            }
            return super.getTargetForProperty(a, b);
        }
        getValue(a, b) {
            switch (b) {
                case 16:
                case 15:
                case 44:
                case 45:
                case 46:
                case 47:
                case 48:
                case 49: return this.al.getValue(a, b);
                case 18: return enumGetBox(BaseControlTheme_$type, a.n);
            }
            return super.getValue(a, b);
        }
        setValue(a, b, c) {
            super.setValue(a, b, c);
            switch (b) {
                case 16:
                case 15:
                case 44:
                case 45:
                case 46:
                case 47:
                case 48:
                case 49:
                    this.al.setValue(a, b, c);
                    break;
                case 18:
                    a.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
            }
        }
    }
    XIconButtonBridge.$t = /*@__PURE__*/ markType(XIconButtonBridge, 'XIconButtonBridge', XButtonBridge.$);
    return XIconButtonBridge;
})();

==> igniteui-webcomponents-inputs-4.8.1-beta.0.tgz: package/esm2015/lib/XIconButtonBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XButtonBridge } from "./XButtonBridge";
import { enumGetBox, EnumUtil, markType } from "igniteui-webcomponents-core";
import { XIconBridge } from "./XIconBridge";
import { BaseControlTheme_$type } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let XIconButtonBridge = /*@__PURE__*/ (() => {
    class XIconButtonBridge extends XButtonBridge {
        constructor(a, b) {
            super(a);
            this.al = null;
            this.al = new XIconBridge(b);
        }
        getTargetForBuildInProperty(a, b) {
            switch (b) {
                case 15:
                case 16:
                case 44:
                case 45:
                case 46:
                case 47:
                case 48:
                case 49: return this.al.t;
            }
            return super.getTargetForBuildInProperty(a, b);
        }
        getTargetForProperty(a, b) {
            switch (a) {
                case 16:
                case 15:
                case 17: return this.al.t.view.s;
            }
            return super.getTargetForProperty(a, b);
        }
        getValue(a, b) {
            switch (b) {
                case 16:
                case 15:
                case 44:
                case 45:
                case 46:
                case 47:
                case 48:
                case 49: return this.al.getValue(a, b);
                case 18: return enumGetBox(BaseControlTheme_$type, a.n);
            }
            return super.getValue(a, b);
        }
        setValue(a, b, c) {
            super.setValue(a, b, c);
            switch (b) {
                case 16:
                case 15:
                case 44:
                case 45:
                case 46:
                case 47:
                case 48:
                case 49:
                    this.al.setValue(a, b, c);
                    break;
                case 18:
                    a.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                    break;
            }
        }
    }
    XIconButtonBridge.$t = /*@__PURE__*/ markType(XIconButtonBridge, 'XIconButtonBridge', XButtonBridge.$);
    return XIconButtonBridge;
})();
